/* Structure for dynamic wide strings */

struct dstr {
  wchar_t *s;		/* The text itself */
  size_t   c;		/* The number of characters for which storage is available */
  size_t   l;		/* The number of characters in the current string */
};

#ifndef DSTR
extern int FillDynamicString(struct dstr *, wchar_t *);
extern void FreeDynamicString (struct dstr *);
extern void InitializeDynamicString (struct dstr *);
extern struct dstr *MakeDynamicString (wchar_t *);
extern  void AppendToDyanmicString (struct dstr *,const wchar_t *);
#endif

